"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sleep = void 0;
const chai_1 = __importStar(require("chai"));
const chai_as_promised_1 = __importDefault(require("chai-as-promised"));
chai_1.default.use(chai_as_promised_1.default);
const Utils_1 = require("./Utils");
function sleep(ms) { return new Promise(resolve => setTimeout(resolve, ms)); }
exports.sleep = sleep;
describe("Reality Modeling utils unit tests", () => {
    it("Settings to json", function () {
        const ccSettings = new Utils_1.CCJobSettings();
        ccSettings.inputs = ["imagesId", "ccOrientationsId"];
        ccSettings.outputs.cesium3DTiles = "cesium3DTiles";
        ccSettings.outputs.contextScene = "contextScene";
        ccSettings.outputs.dgn = "dgn";
        ccSettings.outputs.esri = "esri";
        ccSettings.outputs.fbx = "fbx";
        ccSettings.outputs.las = "las";
        ccSettings.outputs.lodTreeExport = "lodTreeExport";
        ccSettings.outputs.obj = "obj";
        ccSettings.outputs.omr = "omr";
        ccSettings.outputs.opc = "opc";
        ccSettings.outputs.orientations = "orientations";
        ccSettings.outputs.orthophoto = "orthophoto";
        ccSettings.outputs.ply = "ply";
        ccSettings.outputs.pod = "pod";
        ccSettings.outputs.threeMX = "threeMX";
        ccSettings.outputs.threeSM = "threeSM";
        ccSettings.outputs.webReadyScalableMesh = "webReadyScalableMesh";
        ccSettings.engines = 8;
        ccSettings.meshQuality = Utils_1.CCJobQuality.EXTRA;
        ccSettings.cacheSettings = {
            useCache: "useCache",
            createCache: true
        };
        const json = ccSettings.toJson();
        return Promise.all([
            (0, chai_1.expect)(json).to.have.property("inputs"),
            (0, chai_1.expect)(json.inputs).to.have.length.above(0),
            (0, chai_1.expect)(json.inputs).to.deep.include({ "id": "imagesId" }),
            (0, chai_1.expect)(json.inputs).to.deep.include({ "id": "ccOrientationsId" }),
            (0, chai_1.expect)(json).to.have.property("settings"),
            (0, chai_1.expect)(json.settings).to.have.property("outputs"),
            (0, chai_1.expect)(json.settings.processingEngines).to.deep.equal(8),
            (0, chai_1.expect)(json.settings.quality).to.deep.equal(Utils_1.CCJobQuality.EXTRA),
            (0, chai_1.expect)(json.settings.outputs).to.have.length.above(0),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("Cesium 3D Tiles"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("DGN"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("WebReady ScalableMesh"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("FBX"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("ESRI i3s"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("LAS"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("LODTreeExport"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("OBJ"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("OPC"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("OMR"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("CCOrientations"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("Orthophoto/DSM"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("PLY"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("POD"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("3MX"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("3SM"),
            (0, chai_1.expect)(json.settings.outputs).to.deep.include("ContextScene"),
            (0, chai_1.expect)(json.settings).to.have.property("cacheSettings"),
            (0, chai_1.expect)(json.settings.cacheSettings.createCache).to.deep.equal(true),
            (0, chai_1.expect)(json.settings.cacheSettings.useCache).to.deep.equal("useCache"),
        ]);
    });
    it("Settings from json", async function () {
        const json = {
            "inputs": [{ "id": "imagesId" }, { "id": "ccOrientationsId" }],
            "jobSettings": {
                "quality": "Extra",
                "outputs": [
                    { "format": "Cesium 3D Tiles", "id": "cesium3DTilesId" },
                    { "format": "DGN", "id": "dgnId" },
                    { "format": "WebReady ScalableMesh", "id": "webReadyScalableMeshId" },
                    { "format": "FBX", "id": "fbxId" },
                    { "format": "ESRI i3s", "id": "esriId" },
                    { "format": "LAS", "id": "lasId" },
                    { "format": "LODTreeExport", "id": "lodTreeExportId" },
                    { "format": "OBJ", "id": "objId" },
                    { "format": "OPC", "id": "opcId" },
                    { "format": "OMR", "id": "omrId" },
                    { "format": "CCOrientations", "id": "orientationsId" },
                    { "format": "Orthophoto/DSM", "id": "orthophotoId" },
                    { "format": "PLY", "id": "plyId" },
                    { "format": "POD", "id": "podId" },
                    { "format": "3MX", "id": "threeMXId" },
                    { "format": "3SM", "id": "threeSMId" },
                    { "format": "ContextScene", "id": "contextSceneId" },
                ],
                "processingEngines": 5,
                "cacheSettings": {
                    "createCache": true,
                    "useCache": "799b11bd-71cf-481a-b284-bf48f672cd9a"
                },
            }
        };
        const contextCaptureSettings = await Utils_1.CCJobSettings.fromJson(json);
        return Promise.all([
            (0, chai_1.expect)(contextCaptureSettings.meshQuality).to.deep.equal(Utils_1.CCJobQuality.EXTRA),
            (0, chai_1.expect)(contextCaptureSettings.engines).to.deep.equal(5),
            (0, chai_1.expect)(contextCaptureSettings.cacheSettings).to.not.be.undefined,
            (0, chai_1.expect)(contextCaptureSettings.cacheSettings.createCache).to.deep.equal(true),
            (0, chai_1.expect)(contextCaptureSettings.cacheSettings.useCache).to.deep.equal("799b11bd-71cf-481a-b284-bf48f672cd9a"),
            (0, chai_1.expect)(contextCaptureSettings.inputs).to.deep.include("imagesId"),
            (0, chai_1.expect)(contextCaptureSettings.inputs).to.deep.include("ccOrientationsId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.cesium3DTiles).to.deep.equal("cesium3DTilesId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.dgn).to.deep.equal("dgnId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.webReadyScalableMesh).to.deep.equal("webReadyScalableMeshId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.fbx).to.deep.equal("fbxId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.las).to.deep.equal("lasId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.esri).to.deep.equal("esriId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.lodTreeExport).to.deep.equal("lodTreeExportId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.obj).to.deep.equal("objId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.opc).to.deep.equal("opcId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.omr).to.deep.equal("omrId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.orientations).to.deep.equal("orientationsId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.orthophoto).to.deep.equal("orthophotoId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.ply).to.deep.equal("plyId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.pod).to.deep.equal("podId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.threeMX).to.deep.equal("threeMXId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.threeSM).to.deep.equal("threeSMId"),
            (0, chai_1.expect)(contextCaptureSettings.outputs.contextScene).to.deep.equal("contextSceneId"),
        ]);
    });
    it("Settings from json (unexpected output)", async function () {
        const json = {
            "inputs": [{ "id": "imagesId" }, { "id": "ccOrientationsId" }],
            "jobSettings": {
                "outputs": [
                    { "format": "Invalid", "id": "cesium3DTilesId" },
                ],
            }
        };
        const contextCaptureSettings = Utils_1.CCJobSettings.fromJson(json);
        return (0, chai_1.expect)(contextCaptureSettings).to.eventually.be.rejectedWith(Error).and.have.property("message", "Found unexpected output name : Invalid");
    });
});
//# sourceMappingURL=Utils.test.js.map